==> com.liferay.layout.admin.web-3.0.23-sources.jar: com/liferay/layout/admin/web/internal/constants/LayoutAdminWebKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.layout.admin.web.internal.constants;

/**
 * @author Julio Camarero
 */
public class LayoutAdminWebKeys {

	public static final String ASSET_DISPLAY_CONTRIBUTOR_TRACKER =
		"ASSET_DISPLAY_CONTRIBUTOR_TRACKER";

	public static final String DISPLAY_PAGE_DROPDOWN_DEFAULT_EVENT_HANDLER =
		"DISPLAY_PAGE_DROPDOWN_DEFAULT_EVENT_HANDLER";

	public static final String ITEM_SELECTOR = "ITEM_SELECTOR";

	public static final String LAYOUT_COPY_HELPER = "LAYOUT_COPY_HELPER";

	public static final String LAYOUT_PAGE_TEMPLATE_DISPLAY_CONTEXT =
		"LAYOUT_PAGE_TEMPLATE_DISPLAY_CONTEXT";

	public static final String
		LAYOUT_PAGE_TEMPLATE_ENTRY_DROPDOWN_DEFAULT_EVENT_HANDLER =
			"LAYOUT_PAGE_TEMPLATE_ENTRY_DROPDOWN_DEFAULT_EVENT_HANDLER";

	public static final String LAYOUT_PROTOTYPE = "LAYOUT_PROTOTYPE";

	public static final String LAYOUT_PROTOTYPE_DROPDOWN_DEFAULT_EVENT_HANDLER =
		"LAYOUT_PROTOTYPE_DROPDOWN_DEFAULT_EVENT_HANDLER";

}

==> com.liferay.layout.admin.web-3.0.139-sources.jar: com/liferay/layout/admin/web/internal/constants/LayoutAdminWebKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.layout.admin.web.internal.constants;

/**
 * @author Julio Camarero
 */
public class LayoutAdminWebKeys {

	public static final String ASSET_DISPLAY_CONTRIBUTOR_TRACKER =
		"ASSET_DISPLAY_CONTRIBUTOR_TRACKER";

	public static final String DISPLAY_PAGE_DROPDOWN_DEFAULT_EVENT_HANDLER =
		"DISPLAY_PAGE_DROPDOWN_DEFAULT_EVENT_HANDLER";

	public static final String ITEM_SELECTOR = "ITEM_SELECTOR";

	public static final String LAYOUT_COPY_HELPER = "LAYOUT_COPY_HELPER";

	public static final String LAYOUT_PAGE_TEMPLATE_DISPLAY_CONTEXT =
		"LAYOUT_PAGE_TEMPLATE_DISPLAY_CONTEXT";

	public static final String
		LAYOUT_PAGE_TEMPLATE_ENTRY_DROPDOWN_DEFAULT_EVENT_HANDLER =
			"LAYOUT_PAGE_TEMPLATE_ENTRY_DROPDOWN_DEFAULT_EVENT_HANDLER";

	public static final String LAYOUT_PROTOTYPE = "LAYOUT_PROTOTYPE";

	public static final String LAYOUT_PROTOTYPE_DROPDOWN_DEFAULT_EVENT_HANDLER =
		"LAYOUT_PROTOTYPE_DROPDOWN_DEFAULT_EVENT_HANDLER";

	public static final String LAYOUT_TEMPLATE_CONVERTER_REGISTRY =
		"LAYOUT_TEMPLATE_CONVERTER_REGISTRY";

}
